@@ -1,20 +1,18 @@
 #!/usr/bin/env python3
 import click
 
-from .libsimenv.autocomplete import complete_path
+from .libsimenv.repo_path import *
+from .sim_env_list import list_app as entry_list
+from .sim_env_mkgen import mkgen as entry_mkgen
 from .sim_env_spawn import spawn as entry_spawn
 from .sim_env_verify import verify as entry_verify
-from .sim_env_list import list as entry_list
-from .sim_env_mkgen import mkgen as entry_mkgen
-from .libsimenv.repo_path import *
 
 
 @click.group()
 @click.pass_context
 @click.option("--repo-path", envvar='ATOOL_SIMENV_REPO_PATH',
               type=click.Path(exists=True, dir_okay=True, file_okay=False),
-              help='Override the SimEnv repository path given by the environmental variable "ATOOL_SIMENV_REPO_PATH".',
-              autocompletion=complete_path)
+              help='Override the SimEnv repository path given by the environmental variable "ATOOL_SIMENV_REPO_PATH".')
 def cli(ctx, repo_path):
     """
     The simenv utility
