@@ -12,7 +12,7 @@ from .libsimenv.utils import *
 
 @click.command()
 @click.pass_context
-@click.argument("app-name", autocompletion=complete_app_names, type=click.STRING)
+@click.argument("app-name", shell_complete=complete_app_names, type=click.STRING)
 @click.argument("dest-dir", type=click.Path())
 @click.option("-f", "--force", is_flag=True,
               help="If path [new-dir] already exist, remove it before create the new simenv.")
